import { Component } from '../component';
import { Job, JobStep } from '../github/workflows-model';
import { Project } from '../project';
import { Task } from '../tasks';
import { Publisher } from './publisher';
/**
 * (experimental) Project options for release.
 *
 * @experimental
 */
export interface ReleaseProjectOptions {
    /**
     * (experimental) Automatically release new versions every commit to one of branches in `releaseBranches`.
     *
     * @default true
     * @experimental
     */
    readonly releaseEveryCommit?: boolean;
    /**
     * (experimental) CRON schedule to trigger new releases.
     *
     * @default - no scheduled releases
     * @experimental
     */
    readonly releaseSchedule?: string;
    /**
     * (experimental) A directory which will contain artifacts to be published to npm.
     *
     * @default "dist"
     * @experimental
     */
    readonly artifactsDirectory?: string;
    /**
     * (experimental) A set of workflow steps to execute in order to setup the workflow container.
     *
     * @experimental
     */
    readonly releaseWorkflowSetupSteps?: JobStep[];
    /**
     * (experimental) Container image to use for GitHub workflows.
     *
     * @default - default image
     * @experimental
     */
    readonly workflowContainerImage?: string;
    /**
     * (experimental) Version requirement of `jsii-release` which is used to publish modules to npm.
     *
     * @default "latest"
     * @experimental
     */
    readonly jsiiReleaseVersion?: string;
    /**
     * (experimental) Steps to execute after build as part of the release workflow.
     *
     * @default []
     * @experimental
     */
    readonly postBuildSteps?: JobStep[];
    /**
     * (experimental) Checks that after build there are no modified files on git.
     *
     * @default true
     * @experimental
     */
    readonly antitamper?: boolean;
    /**
     * (experimental) Major version to release from the default branch.
     *
     * If this is specified, we bump the latest version of this major version line.
     * If not specified, we bump the global latest version.
     *
     * @default - Major version is not enforced.
     * @experimental
     */
    readonly majorVersion?: number;
    /**
     * (experimental) Bump versions from the default branch as pre-releases (e.g. "beta", "alpha", "pre").
     *
     * @default - normal semantic versions
     * @experimental
     */
    readonly prerelease?: string;
    /**
     * (experimental) The name of the default release workflow.
     *
     * @default "Release"
     * @experimental
     */
    readonly releaseWorkflowName?: string;
    /**
     * (experimental) Defines additional release branches.
     *
     * A workflow will be created for each
     * release branch which will publish releases from commits in this branch.
     * Each release branch _must_ be assigned a major version number which is used
     * to enforce that versions published from that branch always use that major
     * version. If multiple branches are used, the `majorVersion` field must also
     * be provided for the default branch.
     *
     * @default - no additional branches are used for release. you can use
     * `addBranch()` to add additional branches.
     * @experimental
     */
    readonly releaseBranches?: {
        [name: string]: BranchOptions;
    };
}
/**
 * (experimental) Options for `Release`.
 *
 * @experimental
 */
export interface ReleaseOptions extends ReleaseProjectOptions {
    /**
     * (experimental) The task to execute in order to create the release artifacts.
     *
     * Artifacts are
     * expected to reside under `artifactsDirectory` (defaults to `dist/`) once
     * build is complete.
     *
     * @experimental
     */
    readonly task: Task;
    /**
     * (experimental) A name of a .json file to set the `version` field in after a bump.
     *
     * @experimental
     * @example
     *
     * "package.json"
     */
    readonly versionFile: string;
    /**
     * (experimental) The default branch name to release from.
     *
     * Use `majorVersion` to restrict this branch to only publish releases with a
     * specific major version.
     *
     * You can add additional branches using `addBranch()`.
     *
     * @experimental
     */
    readonly branch: string;
}
/**
 * (experimental) Manages releases (currently through GitHub workflows).
 *
 * By default, no branches are released. To add branches, call `addBranch()`.
 *
 * @experimental
 */
export declare class Release extends Component {
    /**
     * (experimental) Package publisher.
     *
     * @experimental
     */
    readonly publisher: Publisher;
    private readonly buildTask;
    private readonly version;
    private readonly postBuildSteps;
    private readonly antitamper;
    private readonly artifactsDirectory;
    private readonly versionFile;
    private readonly releaseSchedule?;
    private readonly releaseEveryCommit;
    private readonly preBuildSteps;
    private readonly containerImage?;
    private readonly branches;
    private readonly jobs;
    private readonly defaultBranch;
    /**
     * @experimental
     */
    constructor(project: Project, options: ReleaseOptions);
    /**
     * (experimental) Adds a release branch.
     *
     * It is a git branch from which releases are published. If a project has more than one release
     * branch, we require that `majorVersion` is also specified for the primary branch in order to
     * ensure branches always release the correct version.
     *
     * @param branch The branch to monitor (e.g. `main`, `v2.x`).
     * @param options Branch definition.
     * @experimental
     */
    addBranch(branch: string, options: BranchOptions): void;
    /**
     * (experimental) Adds jobs to all release workflows.
     *
     * @param jobs The jobs to add (name => job).
     * @experimental
     */
    addJobs(jobs: Record<string, Job>): void;
    /**
     * (experimental) Called before synthesis.
     *
     * @experimental
     */
    preSynthesize(): void;
    private createWorkflow;
}
/**
 * (experimental) Options for a release branch.
 *
 * @experimental
 */
export interface BranchOptions {
    /**
     * (experimental) The name of the release workflow.
     *
     * @default "release-BRANCH"
     * @experimental
     */
    readonly workflowName?: string;
    /**
     * (experimental) The major versions released from this branch.
     *
     * @experimental
     */
    readonly majorVersion: number;
    /**
     * (experimental) Bump the version as a pre-release tag.
     *
     * @default - normal releases
     * @experimental
     */
    readonly prerelease?: string;
}
